@@ -8,7 +8,7 @@ use Devel::hdb::TraceFollow;
 use IO::Socket::INET;
 use IO::File;
 
-our $VERSION = '0.23_15';
+our $VERSION = '0.21001_01';
 
 sub import {
     my $class = shift;
@@ -149,8 +149,6 @@ currently executing line.
 Hover the mouse over a variable to see its value.  It shows the value in
 whichever stack frame is being displayed.  To see the values for variables
 in higher frames, select the appropriate frame from the tab on the left.
-Right-click on a variable to add it to the list of watch expressions on the
-right.
 
 =head3 Watch Expressions
 
@@ -198,45 +196,7 @@ command-line debugger commands
 
 =item L - Open the breakpoint manager
 
-=item b - Open the Quick Breakpoint entry dialog
-
-=item B - Toggle a breakpoint on the current line
-
-=back
-
-The Quick Breakpoint dialog accepts several different types of expressions
-to set unconditional breakpoints:
-
-=over 4
-
-=item <integer>
-
-Sets a breakpoint on a particular line in the file the debugger is currently
-stopped in.
-
-=item subName
-
-Sets a breakpoint for the first line in the named subroutine within the current package.
-
-=item subName:<integer>
-
-Sets a breakpoint for the nth line in the named subroutine within the current package.
-
-=item Some::Package::subName
-
-Sets a breakpoint for the first line in the named subroutine.
-
-=item Some::Package::subName:<integer>
-
-Sets a breakpoint for the nth line in the named subroutine.
-
-=item some/file.pm:<integer>
-
-Sets a breakpoint for a particular line in the named file.
-
-=item .
-
-Toggle a breakpoint on the current line
+=item b - Toggle a breakpoint on the current line
 
 =back
 
